@@ -60,6 +60,17 @@ def get_route_functions(cls: Type) -> Iterable[RouteFunction]:
             yield method
 
 
+def get_all_controller_route_function(
+    controller: Union[Type["ControllerBase"], Type]
+) -> List[RouteFunction]:
+    route_functions: List[RouteFunction] = []
+    for item in dir(controller):
+        attr = getattr(controller, item)
+        if isinstance(attr, RouteFunction):
+            route_functions.append(attr)
+    return route_functions
+
+
 def compute_api_route_function(
     base_cls: Type, api_controller_instance: "APIController"
 ) -> None:
@@ -312,7 +323,7 @@ class APIController:
 
         self._controller_class = cls
         bases = inspect.getmro(cls)
-        for base_cls in bases:
+        for base_cls in reversed(bases):
             if base_cls not in [ControllerBase, ABC, object]:
                 compute_api_route_function(base_cls, self)
 
@@ -366,7 +377,8 @@ class APIController:
 
     def _add_operation_from_route_function(self, route_function: RouteFunction) -> None:
         # converts route functions to Operation model
-        route_function.route.route_params.operation_id = f"{str(uuid.uuid4())[:8]}_controller_{route_function.route.view_func.__name__}"
+        if route_function.route.route_params.operation_id is None:
+            route_function.route.route_params.operation_id = f"{str(uuid.uuid4())[:8]}_controller_{route_function.route.view_func.__name__}"
 
         if (
             self.auth
